package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````\)P$"#0```!8L@```````#0`(``(
M`"@`'``;``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(T*P`
M`-"L```%`````!````$```#DK@``Y#X%".0^!0AP`@``S!(```8`````$```
M`@```/BN``#X/@4(^#X%"/@```#X````!@````0````$````2`$``$B!!`A(
M@00(1````$0````$````!````%'E=&0```````````````````````````8`
M```$````4N5T9.2N``#D/@4(Y#X%"!P!```<`0``!`````$````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````/````
M!````!0````#````1TY5`/"@0P/6E!E'\3>-,X;LO,_CG;,W80```'0````+
M``````````````!$`````````$@```!'`````````$L```!<````/@```#D`
M``!,`````P```%D`````````,0```&$```!5````:P```&T```!I````!```
M`"P``````````````"H```!E````'@``````````````9@```$D```!G````
M"0```'````!2````<P````````!.`````````!\`````````<0````````!1
M````;@``````````````:````"@```!0````.@``````````````6P```#4`
M``!!````1@``````````````$@`````````_```````````````C````````
M`!P````P````#````#(````I````5```````````````70```&P````\````
M8````$T````[````-`````````!`````````````````````5@```&0`````
M````10```%\```!#````/0```"<````!````````````````````````````
M`````````````````````````````````````````````$\`````````````
M```````````````````````/````%````&(`````````````````````````
M$P``````````````$0`````````9`````````````````````````%<`````
M````6`````````!J```````````````0```````````````7````&P``````
M```F````!0```"0````(`````````"\````E````#@```!T`````````8P``
M`"$`````````&@````T````*``````````````!"`````````#,````N````
M`````'(```!>``````````````!*````!P``````````````````````````
M````````````````````6@```"(``````````````&\````8`````````#8`
M````````*P`````````````````````````6````!@```!4`````````4P``
M```````````````````````W`````@`````````@````+0```#@````E````
M3P````@````(`````!`0!"5`!("H`0`!HH8!J$````)/*`0I.*(R1XJ$#`A/
M````40```````````````````%,```!5````5@```%<```!8````60``````
M``!:````7````%T`````````7@```````````````````%\```!B````````
M``````!C````90```&8```!H`````````&H```!L``````````````!N````
M;P```'$`````````R-6R<5GH[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XY[G
M[U][A_F<@6L)0]8,.I<+1Y@%QL6)!9`-%.*>(?_D#K(!BV_$N9Q`:W^:?'^I
MG)MNQ=\?V7%8'+OCDGS49-1\K4OCP#)BV^WAIP(*9J_,9GOP2FOB1\8!0T75
M['U!CL7"Y3\LH2(+(/+;TQWZH6Q@N8WQ#@````````````````````#_`@``
M```````````2````L0``````````````$@```(T#`````````````!(```!X
M`P`````````````2````H0$`````````````$@```+T#`````````````!(`
M``!Z`@`````````````2````$0``````````````(````"``````````````
M`"````!^`P`````````````2````C0$`````````````$@```-X#````````
M`````!(```!N`0`````````````2````@`$`````````````$@```"\#````
M`````````!(```#>`@`````````````2````+`(`````````````$@```/T`
M`````````````!(````<`@`````````````2````H@,`````````````$@``
M`,H!`````````````!(```!(!``````````````2````#00`````````````
M$@```.L"`````````````!(```#F`@`````````````2````F`(`````````
M````$@```.H!`````````````!(```"F`0`````````````2````-0(`````
M````````$@```,L#`````````````!(````Z!``````````````2````+P$`
M````````````$@```-8#`````````````!(````T```````````````2````
MZ`,`````````````$@```%T!`````````````!(```#(```````````````2
M````&@0`````````````$@```+8#`````````````!(````&!```````````
M```2````FP,`````````````$@```'$#`````````````!(````7!0``````
M```````2````00$`````````````$@```/8#`````````````!(```!<`@``
M```````````2````5P,`````````````$@```!`#`````````````!(```!.
M`@`````````````2````J0,`````````````$@```)$"`````````````!(`
M``"K`0`````````````2````8`,`````````````$@```+`#````````````
M`!(```"4`P`````````````2````[```````````````$@```$(`````````
M`````!(```#]`P`````````````2````,@0`````````````$@```-<`````
M`````````!(```#^`0`````````````2````A0(`````````````$@```%`!
M`````````````!(````D!``````````````2````A@,`````````````$@``
M`$8#`````````````!(```#7`@`````````````2````'0$`````````````
M$@```$,"`````````````!(```!4```````````````2````V`$`````````
M````$@```&,``````````````!(```!!!``````````````2````CP``````
M````````$@```$X#`````````````!(```!!`P`````````````2````>```
M````````````$@````L!`````````````!(```"W`0``8)@$"``````2````
MN`0``"#.!`@$````$0`0`)4%``#`O00(]0D``!(`#@#!!0``(+8$")4!```2
M``X`L@0``.S-!`@`````$@`/`%P$``!@004(!````"$`&0"*!````+,$"`P`
M```2``X`004``&#-!`A:````$@`.`%8%``#@T`0(ZEL``!$`$`"@````,)H$
M"``````2````+`4``$!!!0@`````$``8`"X%``!`004(`````"``&`!1!0``
M3$$%"`0````1`!@`6P0``&!!!0@$````(0`9`*@$``!0S00(!0```!(`#@"T
M!0``H+L$""`"```2``X`U00``*"K!`A$````$@`.`%H$``!@004(!````!$`
M&0!5!```@+D$""`"```2``X`!04``,"W!`@?````$@`.`"`%````N00(?```
M`!(`#@!Y!```5$$%"``````0`/'_A00``+!1!0@`````$`#Q_[\$``#`QP0(
ME`0``!(`#@`@`P``),X$"`0````1`!``,@4``/"<!`@`````$@`.`.,$```P
ML@0(Q````!(`#@#Y!```X+<$"!L!```2``X`:@(``"":!`@`````$@```)L$
M``"PG00(,P```!(`#@!R!```5$$%"``````0`/'_904``#"M!`A<````$@`.
M`#D%``!@S`0(/@```!(`#@"!!0``4$$%"`0````1`!@`HP(``&1!!0@3````
M$0`9`*(%``#PM`0(*`$``!(`#@`[!0``L)<$"``````2``P``&QI8G!E<FPN
M<V\N-2XQ,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E
M<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`
M4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!0
M97)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A
M8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X
M=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?
M9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R
M;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R
M;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P
M='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M
M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L
M7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&]P
M96XV-`!L<V5E:S8T`')E860`<'1H<F5A9%]G971S<&5C:69I8P!?7V5R<FYO
M7VQO8V%T:6]N`&-L;W-E`&QI8F,N<V\N-@!?24]?<W1D:6Y?=7-E9`!?7W)E
M9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`
M7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`
M9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M96UC
M<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T
M`%]?8W1Y<&5?8E]L;V,`9V5T=6ED`')E861L:6YK`&5X96-V<`!?7VUE;6-P
M>5]C:&L`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`
M<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS
M;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`'!A<E]C=7)R96YT7V5X96,`
M<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!?9G!?:'<`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI
M=`!N86UE7VQO861?;7E?<&%R7W!L`%A37TEN=&5R;F%L<U]005)?0TQ%05)3
M5$%#2P!S:7IE7VQO861?;7E?<&%R7W!L`'!A<E]M:W1M<&1I<@!P87)?<V5T
M=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`<&%R7VEN:71?96YV`$=,24)#7S(N
M-`!'3$E"0U\R+C,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,RXT
M`$=,24)#7S(N,`````(````#``,````$``````````,````%```````&``<`
M`````````P````,`!``"``(```````,````%``,````#````"```````!0`#
M``,``P`#``,````#`````P`"`````P`#````"0`#``,```````,``P``````
M``````0``P`#``<```````````````,````#``,``````````0`!``$``0`#
M``$``0`!`````0`!``$``P`!``$``0`#``$``0`!``$``0`!``$``0`!``$`
M```!``$``0`!``$````!``$````!``8`%@,``!````!P````%&EI#0``"0#.
M!0``$````!-I:0T```@`V`4``!````!R&6D)```&`.(%```0````$FEI#0``
M!0#N!0``$````'09:0D```0`^`4``!`````0:6D-```#``0&`````````0`"
M`,<"```0`````````!)I:0T```<`[@4``!`````0:6D-```"``0&````````
M\#\%"`8(``!@004(!6```&1!!0@%<0```$`%"`<!```$0`4(!P(```A`!0@'
M`P``#$`%"`<$```00`4(!P4``!1`!0@'!@``&$`%"`<'```<0`4(!T\``"!`
M!0@'"```)$`%"`<*```H0`4(!PL``"Q`!0@'#```,$`%"`<-```T0`4(!PX`
M`#A`!0@'#P``/$`%"`<0``!`0`4(!Q$``$1`!0@'$@``2$`%"`<3``!,0`4(
M!Q0``%!`!0@'%0``5$`%"`<6``!80`4(!Q<``%Q`!0@'&```8$`%"`<9``!D
M0`4(!QH``&A`!0@'&P``;$`%"`<<``!P0`4(!QT``'1`!0@''@``>$`%"`<?
M``!\0`4(!R```(!`!0@'(0``A$`%"`<B``"(0`4(!R,``(Q`!0@':P``D$`%
M"`=8``"40`4(!R0``)A`!0@')0``G$`%"`<F``"@0`4(!R<``*1`!0@'*```
MJ$`%"`<I``"L0`4(!RH``+!`!0@'*P``M$`%"`<L``"X0`4(!RT``+Q`!0@'
M+@``P$`%"`<O``#$0`4(!S```,A`!0@',0``S$`%"`<R``#00`4(!S,``-1`
M!0@'-```V$`%"`<U``#<0`4(!S8``.!`!0@'-P``Y$`%"`<X``#H0`4(!SD`
M`.Q`!0@'.@``\$`%"`<[``#T0`4(!SP``/A`!0@'/0``_$`%"`<^````004(
M!S\```1!!0@'0```"$$%"`=!```,004(!T(``!!!!0@'0P``%$$%"`=$```8
M004(!T4``!Q!!0@'1@``($$%"`='```D004(!T@``"A!!0@'20``+$$%"`=*
M```P004(!TL``#1!!0@'3```.$$%"`=-```\004(!TX``%6)Y5.#[`3H````
M`%N!PSBH``"+D_S___^%TG0%Z)X```#HJ04``.CD-0``6%O)P_\U^#\%"/\E
M_#\%"`````#_)0!`!0AH`````.G@_____R4$0`4(:`@```#IT/____\E"$`%
M"&@0````Z<#_____)0Q`!0AH&````.FP_____R400`4(:"````#IH/____\E
M%$`%"&@H````Z9#_____)1A`!0AH,````.F`_____R4<0`4(:#@```#I</__
M__\E($`%"&A`````Z6#_____)21`!0AH2````.E0_____R4H0`4(:%````#I
M0/____\E+$`%"&A8````Z3#_____)3!`!0AH8````.D@_____R4T0`4(:&@`
M``#I$/____\E.$`%"&AP````Z0#_____)3Q`!0AH>````.GP_O___R5`0`4(
M:(````#IX/[___\E1$`%"&B(````Z=#^____)4A`!0AHD````.G`_O___R5,
M0`4(:)@```#IL/[___\E4$`%"&B@````Z:#^____)51`!0AHJ````.F0_O__
M_R580`4(:+````#I@/[___\E7$`%"&BX````Z7#^____)6!`!0AHP````.E@
M_O___R5D0`4(:,@```#I4/[___\E:$`%"&C0````Z4#^____)6Q`!0AHV```
M`.DP_O___R5P0`4(:.````#I(/[___\E=$`%"&CH````Z1#^____)7A`!0AH
M\````.D`_O___R5\0`4(:/@```#I\/W___\E@$`%"&@``0``Z>#]____)81`
M!0AH"`$``.G0_?___R6(0`4(:!`!``#IP/W___\EC$`%"&@8`0``Z;#]____
M)9!`!0AH(`$``.F@_?___R640`4(:"@!``#ID/W___\EF$`%"&@P`0``Z8#]
M____)9Q`!0AH.`$``.EP_?___R6@0`4(:$`!``#I8/W___\EI$`%"&A(`0``
MZ5#]____):A`!0AH4`$``.E`_?___R6L0`4(:%@!``#I,/W___\EL$`%"&A@
M`0``Z2#]____);1`!0AH:`$``.D0_?___R6X0`4(:'`!``#I`/W___\EO$`%
M"&AX`0``Z?#\____)<!`!0AH@`$``.G@_/___R7$0`4(:(@!``#IT/S___\E
MR$`%"&B0`0``Z<#\____)<Q`!0AHF`$``.FP_/___R700`4(:*`!``#IH/S_
M__\EU$`%"&BH`0``Z9#\____)=A`!0AHL`$``.F`_/___R7<0`4(:+@!``#I
M</S___\EX$`%"&C``0``Z6#\____)>1`!0AHR`$``.E0_/___R7H0`4(:-`!
M``#I0/S___\E[$`%"&C8`0``Z3#\____)?!`!0AHX`$``.D@_/___R7T0`4(
M:.@!``#I$/S___\E^$`%"&CP`0``Z0#\____)?Q`!0AH^`$``.GP^____R4`
M004(:``"``#IX/O___\E!$$%"&@(`@``Z=#[____)0A!!0AH$`(``.G`^___
M_R4,004(:!@"``#IL/O___\E$$$%"&@@`@``Z:#[____)11!!0AH*`(``.F0
M^____R48004(:#`"``#I@/O___\E'$$%"&@X`@``Z7#[____)2!!!0AH0`(`
M`.E@^____R4D004(:$@"``#I4/O___\E*$$%"&A0`@``Z4#[____)2Q!!0AH
M6`(``.DP^____R4P004(:&`"``#I(/O___\E-$$%"&AH`@``Z1#[____)3A!
M!0AH<`(``.D`^____R4\004(:'@"``#I\/K__S'M7HGA@^3P4%12:%#-!`AH
M8,T$"%%6:("Y!`CH+_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/7A!!0@`
M=3^A?$$%"+OP/@4(@>OL/@4(P?L"@^L!.=AS'HVV`````(/``:-\004(_Q2%
M[#X%"*%\004(.=ARZ,8%>$$%"`&#Q`1;7<.-="8`C;PG`````%6)Y8/L&*'T
M/@4(A<!T$K@`````A<!T"<<$)/0^!0C_T,G#D)"0D)"0D)"0D)"0D%6)Y5:+
M=0A3#[8.B?"$R70>H3C0!`B-5@$/MAB)\&:0.-D/M@H/1,*#P@&$R77Q6UY=
MPXVV`````(V\)P````!5,=*)Y5>)QU:#QQQ3@>Q0`0``C;6T_O__B86L_O__
MD(L,EXG(B<O!XQC!Z!@)V(G+P>,(@>,``/\`P>D("=B!X0#_```)R(D$EH/"
M`8/Z$'7.C97H_O__C4WHD(UT)@"+0NPS`C-"U#-"S,'('XE"#(/"!#G*=>B+
MA:S^__^+E:S^__^+`(G1B86H_O__BT$0BXVH_O__BW($BWH(`X6T_O__BU(,
MP<D;C8P(F7F"6HGPB?OWT"'S(=`)V(N=J/[__P'!BX6H_O__P<X"`Y6X_O__
M(?/WT"'X"=B+G:C^__^-E`*9>8):B<C!R!L!P@.]O/[__XG0P<@;P<L"C80'
MF7F"6HG/B86D_O__B<@AW_?0(?`#M<#^__\)^`.%I/[__XG7P<D"B;6D_O__
MB=8AS_?6(=X)_HN]I/[__P.=Q/[__\'*`HVT-YEY@EJ)M;#^__^)QL'.&P.U
ML/[__XGWP<\;C;P[F7F"6HG#B;VD_O__]].)QR'7(<L)^XGW`YVD_O__`XW(
M_O__P<@"(<>)C:3^__^)\??1(=$)^8N]I/[__P.5S/[__\'.`HV,#YEY@EJ)
MC;#^__^)V<')&P.-L/[__XG/P<\;C;PZF7F"6HG:]](AP@.%T/[__XF]I/[_
M_XG?(?<)^HG/`Y6D_O__B86D_O__B<C!RP+WT"'?(?`)^(N]I/[__P.UU/[_
M_\')`HV$!YEY@EJ)A;#^__^+O;#^__^)T,'(&P''B?C!R!N-A`:9>8):B=:)
MA:3^__^)T"'.]]`AV`.=V/[__PGP`X6D_O__B?[!R@*)G:3^__^)^R'6]],A
MRPGSB[6D_O__`XW<_O__P<\"C9P>F7F"6HF=L/[__XG#P<L;`YVP_O__B=[!
MSAN-M#&9>8):B<'WT2'1`Y7@_O__B;6D_O__B<8A_@GQB=X#C:3^__^)E:3^
M__^)VL'(`O?2(<8A^@GRB[6D_O__`[WD_O__P<L"C906F7F"6HF5L/[__XNU
ML/[__XG*P<H;`=:)\L'*&XV4%YEY@EJ)SXF5I/[__XG*(=_WTB'"`X7H_O__
M"?H#E:3^__^)]\')`HF%I/[__XGP(<_WT"'8"?B+O:3^__\#G>S^___!S@*-
MA`>9>8):B86P_O__B[VP_O__B=#!R!L!QXGXP<@;C80#F7F"6HG3B86D_O__
MB=`A\_?0(<@#C?#^__\)V`.%I/[__XG[P<H"B8VD_O__B?DAT_?1(?$)V8N=
MI/[__\'/`HV,"YEY@EJ)C;#^__^+G;#^__^)P<')&P.U]/[__P'+B=G!R1N-
MC`Z9>8):B<:)C:3^__^)P2'^]]$AT0.5^/[__PGQ`XVD_O__B=[!R`*)E:3^
M__^)VB'&]](A^@GRB[6D_O__`[W\_O__P<L"C906F7F"6HF5L/[__XNUL/[_
M_XG*P<H;`=:)\L'*&XV4%YEY@EJ)SXF5I/[__XG*(=_WTB'""?J)]P.5I/[_
M_\')`@.%`/___R'/B86D_O__B?#WT"'8"?B+O:3^___!S@(#G03___^-A`>9
M>8):B?>)A;#^__^)T#'/P<@;,=<#A;#^__^-O#NAZ]ENP<H"B</!RQL#C0C_
M__^-'!^)US'W,<>-O#FAZ]ENB=G!R`+!R1L#M0S___^-#`^)QS'7,=^-O#ZA
MZ]ENB<[!RP+!SAL#E1#___^--#>)WS'',<^-O#JAZ]ENB?+!R0+!RAL#A13_
M__^-%!>)SS'?,?>-O#BAZ]ENB=#!R!L!Q\'.`HGP`YT8____,<@QT,'*`HV<
M`Z'KV6Z)^,'(&P.-'/___XT$`XG3,?,Q^XV<&:'KV6Z)P<'/`L')&P'+B?D#
MM2#___\QT3'!P<@"C;0.H>O9;HG9P<D;`Y4D____C0P.B<8Q_C'>C;0RH>O9
M;HG*P<L"P<H;`=:)V@.]*/___S'",<K!R0*-O!>AZ]ENB?+!RAL#A2S___^-
M%!>)SS'?,?>-O#BAZ]ENB=#!R!L!Q\'.`HGP`YTP____,<@QT,'*`HV<`Z'K
MV6Z)^,'(&P.--/___XT$`XG3,?,Q^XV<&:'KV6Z)P<'/`L')&P'+B?D#M3C_
M__\QT3'!P<@"C;0.H>O9;HG9P<D;`Y4\____C0P.B<8Q_C'>C;0RH>O9;HG*
MP<L"P<H;`=:)V@.]0/___S'",<K!R0*-O!>AZ]ENB?+!RAL#A43___^-%!>)
MSS'?,?>-O#BAZ]ENB=#!R!L!Q\'.`HGP`YU(____,<@QT,'*`HV<`Z'KV6Z)
M^,'(&P.-3/___XT$`XG3,?,Q^XV<&:'KV6Z)P<'/`L')&XT,"XG[`[50____
M,=,QPP.55/___XVT'J'KV6Z)R\'(`L'+&XT<'HG&B96D_O__"?Z)PB'Z(<X)
MUHN5I/[__P.]6/___\')`HVT,MR\&X^)VL'*&XT4%HG.B;VD_O__"<:)SR''
M(=X)_HN]I/[__P.%7/___\'+`HVT-]R\&X^)WXF%I/[__PG/B=B)M;#^__^)
MUL'.&P.UL/[__R'7(<@)QXN%I/[__P.-8/___\'*`HV\.-R\&X^)\,'(&XT$
M!XG7B8VD_O__"=^)T2'9(?<)SXN-I/[__P.=9/___\'.`HV\.=R\&X^)P<')
M&XT,#XGWB9VD_O__"=>)\R'3(<<)WXN=I/[__P.5:/___\'(`HV\.]R\&X^)
MR\'+&XT<'XG'B96D_O__"?>)PB'R(<\)UXN5I/[__P.U;/___\')`HV\.MR\
M&X^)VL'*&XT4%XG/B;6D_O__"<>)SB'?(<8)]XNUI/[__\'+`HV\/MR\&X^)
MUL'.&P.%</___XTT-XG?"<^)A:3^__^)V"'7(<@)QXN%I/[__P.-=/___\'*
M`HV\.-R\&X^)\,'(&XT$!XG7B8VD_O__"=^)T2'9(?<)SXN-I/[__P.=>/__
M_\'.`HV\.=R\&X^)P<')&XT,#XGWB9VD_O__"=>)\R'3(<<)WXN=I/[__P.5
M?/___\'(`HV\.]R\&X^)R\'+&XT<'XG'B96D_O__"?>)PB'R(<\)UXN5I/[_
M_P-U@,')`HV\.MR\&X^)VL'*&XT4%XG/B;6D_O__"<>)SB'&(=\)]XNUI/[_
M_XV\/MR\&X^)UL'.&P-%A,'+`HTT-XG?B86D_O__"<^)V"'((=<)QXN%I/[_
M_P--B,'*`HV\.-R\&X^)\,'(&XT$!XG7B8VD_O__"=^)T2'9(?<)SXN-I/[_
M_P-=C,'.`HV\.=R\&X^)P<')&XT,#XGWB9VD_O__"=>)\R'3(<<)WXN=I/[_
M_P-5D,'(`HV\.]R\&X^)R\'+&XT<'XG'B96D_O__"?>)PB'R(<\)UXN5I/[_
M_P-UE,')`HV\.MR\&X^)VL'*&XT4%XG/B;6D_O__"<>)SB'?(<8)]XNUI/[_
M_P-%F,'+`HV\/MR\&X^)UL'.&XTT-XG?B86D_O__"<^)V"'((=<)QXN%I/[_
M_P--G,'*`HV\.-R\&X^)\,'(&XT$!XG7B8VD_O__"=^)T2'9(?<)SXN-I/[_
M_P-=H,'.`HV\.=R\&X^)P<')&P'/B?&)G:3^__\)T8GS(=,AP0G9BYVD_O__
MP<@"`U6DC8P+W+P;CXG#B8VP_O__B?DQ\\')&S'[`XVP_O__C9P:UL%BRL'/
M`HG*P<H;`=.)^@-UJ#'",<K!R0*-M!;6P6+*B=K!RAL#1:R-%!:)SC'^,=Z-
MM##6P6+*B=#!RP+!R!L!QHG8`WVP,<@QT,'*`HV\!];!8LJ)\,'(&P--M(T$
M!XG7,=\Q]XV\.=;!8LJ)P<')&\'.`@'/`UVXB?$QT3'!C9P+UL%BRHGYP<@"
MP<D;`U6\C0P+B<,Q\S'[C9P:UL%BRHG*P<\"P<H;`=.)^@-UP#'",<K!R0*-
MM!;6P6+*B=K!RAL#1<2-%!:)SC'^,=Z-M##6P6+*B=#!RP+!R!L!QHG8`WW(
M,<@QT,'*`HV\!];!8LJ)\,'(&P--S(T$!XG7,=\Q]XV\.=;!8LJ)P<')&\'.
M`@'/`UW0B?$QT3'!C9P+UL%BRHGYP<@"P<D;`U74C0P+B<,Q\S'[C9P:UL%B
MRHG*P<\"P<H;`=.)^@-UV#'",<K!R0*-M!;6P6+*B=K!RAL#1=R-%!:)SC'^
M,=Z-M##6P6+*B=#!RP+!R!L!QHG8`WW@,<@QT,'*`HV\!];!8LJ)\,'(&P--
MY(T$!XG7,=\Q]XV\.=;!8LJ)P<'.`L')&P-=Z(T,#XGW,=<QQXV\.];!8LJ)
MR\'(`L'+&P-5[(T<'XG',?<QSXV\.M;!8LJ)VL'*&P'7BY6H_O__`U7PP<D"
MC;06UL%BRHG*,<(QVHT4%HG^P<X;`?*+M:S^___!RP*)%@%^!`%>"`%.#`%&
M$('$4`$``%M>7UW#C;8`````C;PG`````%6)Y8/L.(7`B5WTB<.)=?B)??R)
M5=QU$#'`BUWTBW7XBWW\B>Q=PY"A8$$%"(7`B47@=.0/M@,\/71=A,")VG17
M@\(!#[8"/#UT!(3`=?(IVHM%X(LPA?9TOHE=Y(G'B=.-M"8`````BT7DB5PD
M"(DT)(E$)`3HU?#__X7`=0:`/!X]=!N#QP2+-X7V==IFD.N&C;8`````,=+K
MM8UT)@`K?>"+1=S!_P*).(U$'@'I9O___XVV`````(V_`````%6)Y8/L&(U5
M].@R____R<-5B>6#[`BA2$$%"(/X_W0(R<.-M@````"X*,X$".C.____A<!T
M&@^V`(3`=!,\,`^5P`^VP*-(004(R<.-="8`,<#K\8VV`````(V_`````%6)
MY5:)QE.#[!"-7?3K&9"+1?3!X`(#!6!!!0B#P`2+$(72B5#\=?2)VHGPZ*_^
M__^%P'7;@\006UY=PXUT)@!5B>6![$@0``")??R-O>3O__^)7?2)TXEU^&6A
M%````(E%Y#'`B8W4[___QT0D"/\/``")?"0$QP0D,LX$".@M[___A<")QGYW
MC4#_@+P%Y.___P!T8HET)`C'1"0$+P```(D\).AV[___A<!T4L<$)`````#H
MQN___XL`B00DZ*SL__^)="0,B7PD"(E<)`2)!"3H^.W__XM%Y&4S!10```!U
M2HM=](MU^(M]_(GL7<.-M"8`````A<!T!(G&ZY;'!"0`````Z'3O__^+`(D$
M).A:[/__BY74[___B5PD!(E4)`B)!"3H%.S__^NJZ"WN__^-M@````"-O"<`
M````58GE@^P8QP0D`````.@N[___BP")!"3H%.S__\=$)`3_____B00DZ%3L
M___'!"0`````Z`CO__^+`(D$).CNZ___QT0D"`````#'1"0$D*T$"(D$).A&
M[___R<.-="8`58GE4X/L%,<$)`````#HS>[__XL`B00DZ+/K__^)!"3H2^K_
M_XL`BU@$QP0D`````.BJ[O__BP")!"3HD.O__XD$).C8ZO__#[8`B$,8QP0D
M`````.B&[O__BP")!"3H;.O__XD$).@$ZO__BP"+6`3'!"0`````Z&/N__^+
M`(D$).A)Z___B00DZ*'J__^+``^W0!!F)?\!9HE#&L<$)`````#H-^[__XL`
MB00DZ!WK__^)!"3HM>G__XL`BU@$QP0D`````.@4[O__BP")!"3H^NK__\=$
M)`@`````QT0D!,S/!`B)!"3H<NW__XE#',<$)`````#HX^W__XL`B00DZ,GJ
M__^)!"3H8>G__XL`BU@$QP0D`````.C`[?__BP")!"3HINK__XD$).C.Z?__
MBP")0R#'!"0`````Z)WM__^+`(D$).B#ZO__B00DZ!OI__^+`(M8!,<$)```
M``#H>NW__XL`B00DZ&#J__^)!"3H>.S__S'2BP"%P'0CQP0D`````.A4[?__
MBP")!"3H.NK__XD$).A2[/__BP"+4&R)4R3'!"0`````Z"[M__^+`(D$).@4
MZO__B00DZ*SH__^+`(M`!,=`*`````#'!"0`````Z`3M__^+`(D$).CJZ?__
MB00DZ(+H__^+`(M`!,=`+`````#'!"0`````Z-KL__^+`(D$).C`Z?__B00D
MZ%CH__^+`(M8!,<$)`````#HM^S__XL`B00DZ)WI__^)!"3H=>S__XL`B4,P
M@\046UW#C78`C;PG`````%6)Y5>)QU93@>R<````A<!T!8`X`'41@<2<````
M6UY?7<.-M@````")!"3HX.G__X7`B<9TX6:0B30DZ$#J__^%P`^$T````(U8
M$P^V%4+.!`@/MD`3.=`/A-H````/MA5!S@0(.=`/A.,```")/"3H.^K__XD<
M)(E%@.@PZO__BU6`C40"`HD$).C!ZO__B46$B5PD%(E\)!#'1"0,1,X$",=$
M)`C_____QT0D!`$```")!"3H9NO__XU%B(E$)`B+183'!"0#````B40D!.CL
MY___@_C_=!.+19@E`/```#T`0```#X2,````BT6$B00DZ,GI__^+182)!"3H
MONC__XDT).AVZ?__A<`/A3;___^-M@````")-"3H\.G__XD\).A8ZO__@<2<
M````6UY?7<.0C70F``^V4P$Z%4/.!`@/A/#^___I$?___XUV``^V0P$Z!4+.
M!`@/A0W___\/MD,".@5#S@0(#X3(_O__Z?C^__^-=@"+183H@/[__^ER____
MC70F`(V\)P````!5B>53B<.#[!3'!"0`````Z.OJ__^+`(D$).C1Y___B00D
MZ/GI__^)7"0$QP0D`P```(E$)`CH%>C__X7`=`F#Q!0QP%M=PY#'!"0`````
MZ*SJ__^+`(D$).B2Y___B00DZ+KI__^+0!`E`/```#T`0```="W'!"0`````
MZ'_J__^+`(D$).AEY___B00DZ(WI__^+0!`E`/```#T`H```=9V)'"3'1"0$
M`@```.BNY___A<`/E,"#Q!0/ML!;7<-5B>6![$@@``")7?2-G>/O__]EH10`
M``")1>0QP(EU^(E]_.BXY?__QT0D%#W.!`C'1"0,2LX$",=$)`@!$```QT0D
M!`$```")'"2)1"00Z'SI__^%P'D@,=N+5>1E,Q44````B=AU5XM=](MU^(M]
M_(GL7<.-=@"-O>+?___'1"0(`!```(E\)`2)'"3HWNC__X7`B<9XP(U``8D$
M).A=Z/__A<")PW2QB70D"(E\)`2)!"3HA^?__\8$,P#KF^A<Z/__C;8`````
MC;\`````58GE@^P(R>DD____C70F`%6)Y5=6B<93,<"#[#R)TX`Z/0^4P`'#
MB1PDZ&'G__^-5>2)QXGPZ)7W__^%P'0QB00DB470Z$;G__\QR8M5T#G'#X=U
M`0``D`^V!`N(!`J#P0&$P'7R@\0\,<!;7E]=PZ%@004(,=*Y"````(,X`'08
MC;0F`````(/"`8L,D(7)=?:-#)4(````@SV`004(`'0NB4PD!(D$)(E5T.C/
MY/__A<")P:-@004(BU70#X47`0``@\0\N/____];7E]=PXD,),<%@$$%"`$`
M``")5=#H2^?__XM5T(7`B<%TU8T$E0````")1=2)1"0(H6!!!0B)#"2)1"0$
MB4W,Z*#G__^+3<R)#6!!!0B+5=#'1)$$`````(E5Y`^V%H#Z/0^$M@```(32
MB?!U"^FK````9I"$TG0.@\`!#[80@/H]C78`=>XI\(M5U(U$.`(#%6!!!0B)
M!"2)5=#HQ.;__XM5T(7`B0(/A$K___^+5>2A8$$%"(L$D`^V%H32B!!T)(#Z
M/70?@\8!ZPN0@/H]D(UT)@!T#P^V%H/``8/&`832B!!UY\8`/3'29I`/M@P3
MB$P0`8/"`83)=?'IFO[__XM%Y,'@`HE%U.E-____C025`````(E%U.DS____
M,<#I9/___U6)Y5>_8,X$"%93NU;.!`B#[&R-==C'1=!@S@0(QT745LX$",=%
MV&/.!`C'1=Q9S@0(QT7@7LX$",=%Y,S/!`CK*HVV`````(M%"(D4)(E5O(E$
M)`3HUN7__X7`=#J`.P!T*HL&B=^#Q@2)PXGXZ"WV__^%P(G"=`6`.`!URHM5
M"(GXZ)C]__^`.P!UUH/$;%M>7UW#C78`BTT(B0PDZ/WD__^)1<2A/-`$"(D$
M).CMY/__BU6\B10DB47`Z-_D__^+3<")1;2+1<2-3`@!BT6T`<B)!"3H9>7_
M_XM5O,=$)`Q[SP0(QT0D"/_____'1"0$`0```(E4)!B)P:$\T`0(B0PDB4V\
MB40D%(M%"(E$)!#H^>7__XM-O(GXB<KH_?S__^DV____D(VT)@````!5B>57
M5H/L,&6A%````(E%]#'`H130!`B)1=*A&-`$"(E%UJ$<T`0(B47:H2#0!`B)
M1=ZA)-`$"(E%XJ$HT`0(B47FH2S0!`B)1>JA,-`$"(E%[@^W!330!`AFB47R
MN'#.!`CH:/7__[AYS@0(Z%[U__^X@<X$".A4]?__N(K.!`CH2O7__[B1S@0(
MZ$#U__^XH<X$".@V]?__N*W.!`CH+/7__[@HS@0(Z"+U__^XMLX$".@8]?__
MN,#.!`CH#O7__[C*S@0(Z`3U__^XU\X$".CZ]/__N.#.!`CH\/3__[CKS@0(
MZ(;T__^%P'0,B<*XMLX$".CV^___N/S.!`CH;/3__X7`=`R)PK@.SP0(Z-S[
M__^X&<\$".A2]/__A<!T+HG"N*W.!`CHPOO__[I%SP0(N)'.!`CHL_O__XM%
M]&4S!10```!U1X/$,%Y?7<.X*<\$".@6]/__A<!T$HG"N"C.!`CHAOO__^O"
MC70F`(UUX[\ZSP0(N0H```#SIG6MC57MN"C.!`CH8OO__^N>Z)OC__^-="8`
MC;PG`````%6)Y8/L&.@%X___B00DZ-WB__^)PC'`A=)T`HL"R<.058GE5E.#
M[!"+70B%VW1A@#L`=%R)'"3HE.+__XU$`_\YPP^#Z````(LU.-`$"`^V"`^V
M%CC1=`SK6HVV`````#@(=5"#Z`$YPW+U.=B-=@!U5@^V`#H&#X23````B74(
M@\006UY=Z67D__^0C70F`,<$)`(```#HU.+__X7`=`5FQP`N`(/$$%M>7<.-
M="8`.!!TMX/H`3G#<O4YV(UV`'2PC;8`````@^@!.<-S!P^V$#H6=/*)PC'`
M*=J-2@*!^0`0``!WOH/"`<=$)`P`$```B50D"(E<)`3'!"2@004(Z'K?__^X
MH$$%".N8C78`QP0D`@```.A4XO__B<(QP(72=(%FQP(N`(G0Z77___^+-3C0
M!`CI,/___Y"-="8`58GE5U93@^P<BW4(B30DZ,S^__\/M@B)QXG#A,ET(*$X
MT`0(C5<!#[8`C;8`````.,$/M@H/1-J#P@&$R77QZ%SR__^%P'0>A?9T&H`^
M`)!T%,=$)`1'SP0(B1PDZ+[A__\YV'0(@\0<6UY?7<.#Q!R)\%M>7UWI9/;_
M_XUT)@!5B>6#Y/!64X/L.(U%$(E$)`B-10R)1"0$C44(B00DZ+SB___'1"0(
M8)@$",=$)`1@F`0(QP0D,)H$".A0$P``QP0D`````.C$W___@#@`=3OHJM__
M_X7`HZ!1!0@/A+$!``")!"3H9>#__\<$)`````#H>>+__XL`B00DZ%_?__^)
M!"3HQ^'__\8``,<$)`````#H6.+__XL`B00DZ#[?__^)!"3H5N+__X`(`L<$
M)`````#H-^+__XL`B00DZ!W?__^)!"3H->+__S')@`@!BT4(B4PD+(/`!8E$
M)"C?;"0HV`7`T`0(W07(T`0(V<G?Z=W8#X<&`0``P>`"B00DZ%OA__^+=0RC
MK%$%"(L6QT`$3,\$",=`".#0!`C'0`Q/SP0(B1"+70C'!:A1!0@$````@_L!
M?A:Z`0```(UV`(L,EHE,D`R#P@$YTW_R@\,#QP28`````(E$)`RAH%$%"(E<
M)`C'1"00`````,=$)`2@S`0(B00DZ%/=__^%P(G#=#VAH%$%"(D$).@`X/__
MN*'.!`CH=O#__X7`=#JAH%$%"(D$).@%W?__Z-#>__^#Q#B)V%M>B>Q=PY"-
M="8`H:!1!0B)!"3HH]W__XG#Z[*-M"8`````H:11!0B%P'0*B00DZ)?]___K
ML[BMS@0(Z!OP__^%P*.D404(=*#KX<=$)`1D004(QP0D4\X$".@LX/__QP0D
M`0```.@@X?__58GE5U93@>Q,$```BT4(98L5%````(E5Y#'2BW4,B874[___
MN*W.!`CHPN___XL=.-`$"(E<)`2)QXN%U.___XD$).@XW___A<!T,8N5U.__
M_[C*S@0(Z!3W__^+5>1E,Q44````BX74[___#X6I`0``@<1,$```6UY?7<.+
ME=3O__^)%"3H9=[__XDT)(F%T.___Z$\T`0(B40D!.@NW___A<")QG2DBY70
M[___@\(!B970[___D(`^`+A"S@0(#T3PA?]T%(ET)`2)/"3H'>#__X7`#X39
M````B30DZ`W>__\/ME0&_SH3=1:-%`:0#[9*_H/H`<9"_P"#Z@$Z"W3N`X70
M[___/?\/```/CSG___^+E=3O__^-A>3O__^)7"04B70D$,=$)`Q[SP0(B50D
M&,=$)`@`$```QT0D!`$```")!"3H%=___\<$)`````#H>=___XL`B00DZ%_<
M__^)!"3HA][__XV5Y.___XE4)`3'!"0#````B40D".A]V___A<!U+<<$)```
M``#H/=___XL`B00DZ"/<__^)!"3H2][__XM`$"4`\```/0"```!T)*$\T`0(
MQP0D`````(E$)`3H!][__X7`B<8/A>7^___I=/[__XV%Y.___\=$)`0!````
MB00DZ$+<__^%P'7"C97D[___N,K.!`CH;O7__XV5Y.___XD4).@`W___B874
M[___Z4'^___HD-W__U6)Y5=64X'L3($``(M%"&6+%10```")5>0QTL>%*'__
M_U+/!`C'A2Q___]:SP0(B84$?___N*W.!`C'A3!___]"S@0(QX4T?___S,\$
M",>%$'___P[/!`C'A11___\'SP0(QX48?___7\\$",>%''___U7/!`C'A2!_
M__]GSP0(QX4D?___S,\$",>%.'___VO/!`C'A3Q___]PSP0(QX5`?___S,\$
M".@C[?__A<!T"8`X``^%=@,``(VV`````.@[^?__A<")QP^$B0,```^V'X3;
M="+H==O__XGZC78`BP@/OMOV!%D(=0/&`E^#P@$/MAJ$VW7HC9T4?___N`[/
M!`CK$8UV`(L#@\,$@#@`#X2*`@``Z+7L__^%P(G&=.?HBO+__X7`=-Z)-"3H
MOMW__X7`=-*)QHDT).B0V___B3PDB</HAMO__XV4`P0$``")%"2)E?1^___H
M$=S__XN5]'[__XD4)(G#B87\?O__Z/O;__^+#3C0!`B)?"0<QT0D&$?/!`B)
M="00B4PD%,=$)`QYSP0(B84`?___QT0D"/_____'1"0$`0```(D$).B+W/__
MB[T`?___QT0D!.T!``")/"3HE=C__[A9S@0(Z/OK__^%P`^$NP(``(D$).@+
MW?__BY4$?___B40D!(L"B00DZ.?[__^%P(G"#X25`@``B10DB97T?O__Z+_:
M__^+E?1^__^#^`.)A?A^__]^/HUT`OR_@L\$"+D%````\Z9U+(.]^'[__P0/
MA)\!``"+O?A^__^+#3C0!`@/MD0Z^SH!#X2&`0``C;8`````B94$?___Z'7K
M__^%P'4DBX4$?___QT0D!`````")!"3HZ]O__X7`B84$?___#X45`@``ND7/
M!`BX*,X$".BN\O__,?;HI]?__XN5`'___\=$)!S,SP0(QT0D#*#/!`C'1"0(
M_____XE4)!#'1"0$`0```(E$)!BA.-`$"(D<)(E$)!3H6-O__XN]`'___^M6
MZ#O7__^#.!%U88VV`````.A+U___BPTXT`0(@\8!QT0D(,S/!`B)="0<B7PD
M$(E,)!3'1"0,KL\$"(E$)!C'1"0(_____\=$)`0!````B1PDZ/K:___'1"0$
M[0$``(D<).@*U___@_C_=)6+O0!___^)/"3H=]C__XG:N*W.!`CHV_'__XD<
M).BS\___BU7D93,5%````(N%_'[__P^%708``('$3($``%M>7UW#9I"-M2Q_
M__^[4L\$".L-C78`BQZ#Q@2`.P!T&XG8Z._O__\QTH7`=.F)'"3H(=O__X7`
MB<)TVXG6Z5S]__^-="8`B[T$?___BW\$A?^)O01___\/A&G^__^)/"2)E?1^
M___HR]C__XN5]'[__X/X`P^&3/[__XUT!_RY!0```+^'SP0(\Z8/A#S^___I
M,?[__Y")!"2)A?1^___H\O+__XN%]'[__XD$).BDVO__B87\?O__Z2;___^0
MC9T\?___N&O/!`B0C70F`.ACZ?__A<!T$(D$).AWVO__A<`/A>$$``"+`X/#
M!(`X`'7=O[_/!`CI8_S__XUV`(N-!'___XL1Z5[]__^-=@#'1"0,`@```,=$
M)`3N____QT0D"/____^)!"3H6-;__XN-!'___XV51'___\=$)`@&````B50D
M!(D,).C(UO__@+U$?___`'4-@+U%?___0P^$:P0``(N%!'___\=$)`P`````
MQT0D!`````#'1"0(`````(D$).C\U?__C95@____QX5$____`2-%9\>%2/__
M_XFKS>_'A4S____^W+J8QX50____=E0R$,>%5/____#ATL/'A5C___\`````
MQX5<____`````,=%H`````")E>1^__^)G?A^__^0C70F`(N5!'___XV%1'__
M_\=$)`@`@```B40D!(D4).@(UO__A<")PP^.?@$``(N-6/___XV]1'___XN%
M7/___XT4V3G*@]``B85<____B=C!Z!T!A5S___^+1:")E5C___^%P'16OT``
M```IQSG[C8U@____#T[[C00!C95$?___B7PD"(E4)`2)!"3HF];__XM%H`'X
M@_A`B46@#X5B____C8U$?___*?N-A43___^-/#GH]-G__XUT)@"#^S\/CKP`
M```Q]I"-="8`BP0WB85@____BT0W!(F%9/___XM$-PB)A6C___^+1#<,B85L
M____BT0W$(F%</___XM$-Q2)A73___^+1#<8B85X____BT0W'(F%?/___XM$
M-R")18"+1#<DB46$BT0W*(E%B(M$-RR)18R+1#<PB460BT0W-(E%E(M$-SB)
M19B+1#<\@\9`B46<C85$____Z$O9__^)V"GP@_@_#X]>____@^M`B=C!Z`:)
MPL'B!HU\.D`ITXE\)`2-O6#____'1"0,1````(E<)`B)/"3H;=3__XE=H.E=
M_O__D(UT)@"+C01___^+G?A^__^)#"3H_-7__XNU6/___XN57/___XGPP>@#
M@^`_QH0%8/___X"#P`&#^#@/CZ<!``"Y.````(V]8/___RG!C00'B97T?O__
MB4PD",=$)`0`````B00DZ,K3__^+E?1^__^)T,'H&(A%F(G0P>@0B$69B=#!
MZ`B(19J)\,'H&(A%G(GPP>@0B$6=B?#!Z`B(19Z)\#'VB$6?C85$____B%6;
MC7VGZ$S8__^+E43___^)T<'I&(G(B$W0B='!Z1"(3=&)T8A5TXN52/___\'I
M"(A-THG1P>D8B$W4B='!Z1"(3=6)T8A5UXN53/___\'I"(A-UHG1P>D8B$W8
MB='!Z1"(3=F)T8A5VXN54/___\'I"(A-VHG1P>D8B$W<B='!Z1"(3=V)T8A5
MWXN55/___\'I"(A-WHG1P>D8B$W@B='!Z1"(3>&)T<'I"(A-XHA5X^L(C78`
M#[9$-=`/ML"#Q@&)/"2#QP*)1"00QT0D#)O/!`C'1"0(_____\=$)`0!````
MZ'[5__^#_A1UR<9%SP"-5:?'1"0<S,\$"(L-.-`$"(N]`'___XE4)!C'1"0,
MC,\$"(E,)!2)?"00QT0D"/_____'1"0$`0```(D<).@RU?__Z4CZ__^-O6#_
M__^Y0````"G!C00'B4PD"(F5]'[__\=$)`0`````B00DZ"/2__^-A43____H
MZ-;__XN]Y'[__[D.````,<#SJXN5]'[__^DZ_O__B<?I9O?__X"]1G___T$/
MA8C[__^`O4=___]##X5[^___@+U(?___2`^%;OO__X"]27___T4/A6'[__^+
MO01____'1"0,`@```,=$)`3&____QT0D"/____^)/"3H7='__XV%1'___\=$
M)`@I````B40D!(D\).C3T?__C95$?___QT0D',S/!`CIYO[__^B;T___C70F
M`(V\)P````!5B>575E.#["S'!"0`````Z)O4__^+`(D$).B!T?__B00DZ/G1
M___&``&XD<X$".B<X___A<!T"8`X,0^$%P,``(VT)@````#H$^[__\<$)```
M``#H5]3__XL`B00DZ#W1___'1"0,"P```,=$)`@!````QT0D!,;/!`B)!"3H
MS=#__X7`#X3=````BT`,,?:[`0```(M`&(E%Y*&H404(@_@!?SKILP```(VV
M`````(M'#(L5K%$%"(L4FHE$)`2)%"3H"-3__X7`#X6(````H:A1!0B#PP&#
MQ@$YV'Y^QP0D`````.C%T___BP")!"3HJ]#__XM5Y,=$)`P`````B70D"(E4
M)`2)!"3H$-+__X7`=$2+./9'"01UE,<$)`````#HB-/__XL`B00DZ&[0___'
M1"0,`@```,=$)`@`````B7PD!(D$).C2T___Z6#___^0C70F`*&H404(C5#_
M.?(/A(`!``#'!"0`````Z#S3__^+`(D$).@BT/__QT0D#`4```#'1"0(`0``
M`,=$)`3+SP0(B00DZ++/__^%P(G#=#Z+0`R+,,<$)`````#H^]+__XL`B00D
MZ.'/___'1"0(S<\$"(ET)`2)!"3HG<___XM##(L8]D,*0`^%3@$``,<$)```
M``#HPM+__XL`B00DZ*C/___'1"0,!0```,=$)`@!````QT0D!.G.!`B)!"3H
M.,___X7`B<-T/[C*S@0(Z*CA__^%P(G&#X0^`0``BT,,BSC'!"0`````Z&W2
M__^+`(D$).A3S___B70D"(E\)`2)!"3H$\___\<$)`````#H1]+__XL`B00D
MZ"W/__^)!"3HI<___\8``,<$)`````#H)M+__XL`B00DZ`S/__^)!"3H1-+_
M_\<``````+BMS@0(Z"3A__^%P*.D404(#X3G````QT0D!.T!``")!"3HE\W_
M_X/X$70-A<!T"8/X_P^%*@$``(/$+%M>7UW#D(UT)@"#^`$/CG?^__^[`0``
M`&:0QP0D`````(/#`>BIT?__BP")!"3HC\[__XM5Y(E4)`2)!"3H(,[__SD=
MJ%$%"'_0Z3O^__^-=@#'!"0`````Z'31__^+`(D$).A:SO__B5PD!(D$).@N
MT/__Z8O^__^0@'@!``^$Z_S__XVV`````.G4_/__C78`H:Q1!0B+.(M##(LP
MQP0D`````.@HT?__BP")!"3H#L[__XGYB?+HU>#__^F]_O__H:Q1!0B)!"3H
M4_+__XL]K%$%"*.D404(BT,,BS#V1@D$#X26````BT8,B7PD!(D$).CJSO__
MB<:+0PR+&/9#"01T1HM##(E$)`BAK%$%"(ET)`R+`,<$)$#0!`B)1"0$Z/O/
M__^)1"0,H:11!0B)1"0(H:Q1!0B+`,<$)'#0!`B)1"0$Z-?/___'!"0`````
MZ'O0__^+`(D$).AAS?__QT0D#`(```#'1"0(`````(E<)`2)!"3HQ=#__^N)
MQP0D`````.A'T/__BP")!"3H+<W__\=$)`P"````QT0D"`````")="0$B00D
MZ)'0___I-O___XVV`````(V_`````%6)Y8/L&,<$)`````#H_L___XL`B00D
MZ.3,___'1"0,TL\$",=$)`@@F@0(QT0D!-S/!`B)!"3HM,___\G#9I!5B>6#
M["C'!"0`````Z+[/__^+`(D$).BDS/__B00DZ)S____'!"0`````Z*#/__^+
M`(D$).B&S/__QT0D%`````#'1"00S,\$",=$)`S,SP0(QT0D",#'!`C'1"0$
M^,\$"(D$).@VS?__R<.0D)"058GE4^@R````@</;<@``@^P0BX-0`0``B40D
M#(M%$(E$)`B+10R)1"0$BT4(B00DZ(O+__^#Q!!;7<.+'"3#D%6)Y5W#9F8N
M#Q^$``````!5B>575E/HX/___X'#B7(``(/L'.@WRO__C;OP_O__C8/P_O__
M*<?!_P*%_W0D,?:+11")1"0(BT4,B40D!(M%"(D$)/^4L_#^__^#Q@$Y_G+>
M@\0<6UY?7<.0D)"0D)!5B>53@^P$H>0^!0B#^/]T$[OD/@4(9I"#ZP3_T(L#
M@_C_=?2#Q`1;7<.0D%6)Y5.#[`3H`````%N!P_QQ``#H',___UE;R<,`````
M```````````````````````````#`````0`"`%!!4E]#3$5!3@`O<')O8R]S
M96QF+V5X90`N+@`E<R\E<P`O<')O8R\E:2\E<P!,24)0051(`$193$1?3$E"
M4D%265]0051(`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?5$5-4`!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]04D]'3D%-10!005)?05)'0P!005)?05)'5E\P`%!!
M4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!0
M05)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`
M<&%R+0`M90`M+0!#.EQ414U0`"]T;7``5$5-4$1)4@!435``55-%4@!54T52
M3D%-10`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)3`R>``E
M<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`4UE35$5-`$%21U8`&`!P
M97)L`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`+P`Z`````%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@``````W0!`@/T`0()7,Z(&5X96-U=&EO;B!O9B`E<R!F
M86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R
M=&EN9R!W:71H("5I+@H`````````````````@/___\]!<&%R+G!L````````
M`````",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD
M97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@
M<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I
M;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@
M1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]
M*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T
M96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C
M875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T
M<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N
M9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@
M("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D
M:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@
M86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@
M82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F
M:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@
M("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@
M;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O
M9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@
M("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@
M("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E
M=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S
M>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@
M("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H
M97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@
M*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=6
M7S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF
M(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A
M;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F
M(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@
M("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@
M(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@
M7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@
M7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(
M+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@
M("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M
M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@
M("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T
M+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@
M("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@
M("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U
M+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@
M("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE
M*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]
M+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@
M("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R
M8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@
M("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@
M("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N
M(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL
M96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R![
M"B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME
M>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE
M<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[
M(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U
M:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R
M(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F
M:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@
M)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I
M.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL
M92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@
M("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.
M;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI
M>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A
M9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P
M.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S
M('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R
M97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U
M<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@
M97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N
M86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP
M;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@
M/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A
M<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP
M87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]
M('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T
M86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@
M('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@
M(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T
M:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T
M:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@
M86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL
M('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*
M("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@
M("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@
M('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@
M:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O
M7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@
M("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@
M("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@
M/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*
M("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E
M;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@
M("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@
M("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@
M("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@
M4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI
M=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R
M+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA
M;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R
M8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@
M("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@
M?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@
M("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D
M;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/
M<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`]
M(%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO
M9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E
M871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D
M97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@
M?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@
M("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@
M("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@
M("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D
M97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B
M=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@
M<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*
M("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@
M('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E
M<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@
M("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*
M("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E
M<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N
M;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O
M6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA
M:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@
M("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F
M('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@
M9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@
M("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME
M>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,[
M"@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E
M>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS
M;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I
M;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@
M("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@
M("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D
M,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@
M("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@
M("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@
M("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@
M:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I
M92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN
M;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^
M.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@
M("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@
M("`@("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T
M;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT
M(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@
M("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E
M<BYP;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&
M24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT
M9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*
M("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@
M("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T
M:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA
M;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@
M(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E
M<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@
M("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L
M(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@
M>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE
M7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@
M?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I
M;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P
M-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R
M97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@
M(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R
M;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U
M="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*
M("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@
M("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@
M("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B
M)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O
M"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@
M("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA
M;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@
M("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T
M<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@
M("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]
M?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H
M;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E
M4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@
M1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL
M93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK
M<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R![
M"B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$
M>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S
M=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S
M.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*
M("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@
M("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C
M.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@
M("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*
M("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI
M=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE
M879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@
M(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN
M,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I
M;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@
M4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?
M<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M
M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY
M("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<
M7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E
M9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@
M("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@
M9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@
M("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@
M("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D
M=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA
M;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@
M("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@
M("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F
M:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@
M("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@
M("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@
M("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R
M;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@
M("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N
M86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X
M(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C
M<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE
M;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F
M:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@
M("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA
M;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@
M("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E
M<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E
M=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@
M("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@
M("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@
M("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D
M:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@
M("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N
M86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@
M(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@
M*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@
M("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N
M.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$
M14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@
M(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%2
M7R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N
M(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I
M9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?
M0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM0
M05)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI
M+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*
M("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB
M.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@
M?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC
M(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA
M9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA
M;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$R"@I?7T5.1%]?"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````____
M_P````#_____```````````!`````0````$```"R`@```0```+T"```!````
MQP(```$````6`P```0```&0$```,````L)<$"`T```#LS00(!````(R!!`CU
M_O]OZ(0$"`4```"`C00(!@```$"&!`@*````#@8```L````0````%0``````
M```#````]#\%"`(```"``@``%````!$````7````,)4$"!$````8E00($@``
M`!@````3````"````/[__V]XE`0(____;P(```#P__]OCI,$"```````````
M``````````````````````````````````````````````````````````#X
M/@4(``````````#VEP0(!I@$"!:8!`@FF`0(-I@$"$:8!`A6F`0(9I@$"':8
M!`B&F`0(EI@$"*:8!`BVF`0(QI@$"-:8!`CFF`0(]I@$"`:9!`@6F00()ID$
M"#:9!`A&F00(5ID$"&:9!`AVF00(AID$"):9!`BFF00(MID$",:9!`C6F00(
MYID$"/:9!`@&F@0(%IH$""::!`@VF@0(1IH$"%::!`AFF@0(=IH$"(::!`B6
MF@0(IIH$"+::!`C&F@0(UIH$".::!`CVF@0(!IL$"!:;!`@FFP0(-IL$"$:;
M!`A6FP0(9IL$"':;!`B&FP0(EIL$"*:;!`BVFP0(QIL$"-:;!`CFFP0(]IL$
M"`:<!`@6G`0()IP$"#:<!`A&G`0(5IP$"&:<!`AVG`0(AIP$"):<!`BFG`0(
MMIP$",:<!`C6G`0(YIP$"```````````_____]#0!`CI6P``1T-#.B`H56)U
M;G1U(#0N-"XT+31U8G5N='4Q*2`T+C0N-```+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?
M9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP
M;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````
M````````````````````````````"P````$````"````-($$"#0!```3````
M```````````!`````````!,````'`````@```$B!!`A(`0``(```````````
M````!``````````A````!P````(```!H@00(:`$``"0```````````````0`
M````````.`````4````"````C($$"(P!``!<`P``!@`````````$````!```
M`#0```#V__]O`@```.B$!`CH!```6`$```8`````````!`````0````^````
M"P````(```!`A@0(0`8``$`'```'`````0````0````0````1@````,````"
M````@(T$"(`-```.!@`````````````!`````````$X```#___]O`@```(Z3
M!`B.$P``Z`````8``````````@````(```!;````_O__;P(```!XE`0(>!0`
M`*`````'`````@````0`````````:@````D````"````&)4$"!@5```8````
M!@`````````$````"````',````)`````@```#"5!`@P%0``@`(```8````-
M````!`````@```!\`````0````8```"PEP0(L!<``#````````````````0`
M````````=P````$````&````X)<$".`7```0!0`````````````$````!```
M`((````!````!@```/"<!`CP'```_#``````````````$`````````"(````
M`0````8```#LS00([$T``!P```````````````0`````````C@````$````"
M````(,X$""!.``"J7@`````````````@`````````)8````!`````@```,PL
M!0C,K```!```````````````!`````````"@`````0````,```#D/@4(Y*X`
M``@```````````````0`````````IP````$````#````[#X%".RN```(````
M```````````$`````````*X````!`````P```/0^!0CTK@``!```````````
M````!`````````"S````!@````,```#X/@4(^*X``/@````'``````````0`
M```(````O`````$````#````\#\%"/"O```$```````````````$````!```
M`,$````!`````P```/0_!0CTKP``3`$`````````````!`````0```#*````
M`0````,```!`004(0+$``!0```````````````0`````````T`````@````#
M````8$$%"%2Q``!0$``````````````@`````````-4````!````,```````
M``!4L0``(P```````````````0````$````!`````P``````````````=[$`
5`-X```````````````$`````````
